@@ -144,8 +144,25 @@ int verbose;
     char *cipher_list;
 
     if (ssl_active_flag) {
-	/* the cipher list *can* be NULL ... useless but it happens! */
+#ifdef SSLEAY8
+        char *p;
+	char buf[1024];
+	int i;
+
+	/* grab the full list of ciphers */
+	i=0;
+	buf[0]='\0';
+	while((p=SSL_get_cipher_list(ssl_con,i++))!=NULL) {
+	  if (i>0)
+	    strcat(buf,":");
+	  strcat(buf,p);
+	}
+	cipher_list=buf;
+#else /* !SSLEAY8 */
 	cipher_list=SSL_get_cipher(ssl_con);
+#endif /* !SSLEAY8 */
+
+	/* the cipher list *can* be NULL ... useless but it happens! */
 	if (cipher_list==NULL)
 	    cipher_list="<NULL>";
 	fprintf(stderr,"[SSL cipher=%s]\r\n",cipher_list);
