@@ -2303,14 +2303,14 @@ tn(argc, argv)
 		 *
 		 */
 		if (strcmp(portp,"http")==0)
-		    sin.sin_port = 80;
+		    sin.sin_port = htons(80);
 		else if (strcmp(portp,"https")==0)
-		    sin.sin_port = 443;
+		    sin.sin_port = htons(443);
 		else if (strcmp(portp,"ssl-telnet")==0)
-		    sin.sin_port = 151;
+		    sin.sin_port = htons(151);
 		/* include the offical IANA port! */
 		else if (strcmp(portp,"telnets")==0)
-		    sin.sin_port=992;
+		    sin.sin_port=htons(992);
 		else
 #endif /* USE_SSL */
                 {
@@ -2320,9 +2320,12 @@ tn(argc, argv)
 		}
 	    }
 	} else {
+#if 0
+/* this construct causes gcc 2.7.2 on solaris 2.5.1 to segv during compile */
 #if	!defined(htons)
 	    u_short htons();
 #endif	/* !defined(htons) */
+#endif
 	    sin.sin_port = htons(sin.sin_port);
 	}
     } else {
