@@ -761,6 +761,9 @@ NetClose(fd)
 {
 #ifdef USE_SSL
     if (ssl_active_flag) {
+	if (ssl_debug_flag)
+	  BIO_printf(bio_err,"NetClose: calling SSL_shutdown\n");
+	SSL_shutdown(ssl_con);
 	SSL_free(ssl_con);
 	ssl_con=NULL;
 	ssl_active_flag=0;
