@@ -450,7 +450,7 @@ wontoption(option)
 	     * at the moment --tjh 
 	     */
             case TELOPT_AUTHENTICATION:
-		if (ssl_secure_flag) {
+		if (ssl_secure_flag && !ssl_only_flag) {
 		    fflush(stderr);
 		    printf("[SSL not available]\n");
 		    fflush(stdout);
@@ -594,7 +594,7 @@ dontoption(option)
 		break;
 #ifdef USE_SSL
             case TELOPT_AUTHENTICATION:
-		if (ssl_secure_flag) {
+		if (ssl_secure_flag && !ssl_only_flag) {
 		    fflush(stderr);
 		    printf("[SSL not available]\n");
 		    fflush(stdout);
