@@ -245,19 +245,11 @@ extern int	needtermstat;
 
 #ifdef USE_SSL
 
-#include "crypto.h"
-#include "x509.h"
-#include "ssl.h"
-
-extern SSL *ssl_con;
-extern int ssl_only_flag;
-extern int ssl_debug_flag;
-extern int ssl_active_flag;
-
-extern int ssl_disabled_flag;
+#include "../lib/libtelnet/sslapp.h"
 
 /* make telnetd global debug flag visible */
 extern int debug;
+
 #endif /* USE_SSL */
 
 #ifdef OLDENCRYPT
