@@ -53,6 +53,10 @@
 /* I'm working on having this work as is with SunOS 5.x */
 #ifndef USE_SRALOGIN
 #undef _PATH_LOGIN
+#ifdef __bsdi__
+#define	_PATH_LOGIN	"/usr/bin/login"
+#else 
 #define	_PATH_LOGIN	"/bin/login"
-#endif /* USE_SRALOGIN */
+#endif
+#endif /* !USE_SRALOGIN */
 
